=======
Plugins
=======
.. currentmodule:: polars

Plugins allow for extending Polars' functionality. See the
`user guide <https://docs.pola.rs/user-guide/expressions/plugins/>`_ for more information
and resources.

Available plugin utility functions are:

.. automodule:: polars.plugins
    :members:
    :autosummary:
    :autosummary-no-titles:
